function x = lu_tridiag(n, a, b)
    d = zeros(n, 1);
    u = zeros(n - 1, 1);
    l = zeros(n - 1, 1);

    d(1) = a(1,1);
    u(1) = a(1,2);

    for i = 2:(n-1)
        u(i) = a(i, i+1);
        l(i-1) = a(i, i-1) / d(i-1);
        d(i) = a(i,i) - l(i-1) * u(i);
    end

    l(n-1) =  a(n,n-1) / d(n-1);
    d(n) =  a(n,n) - l(n-1) * u(n-1);

    y = descente(n, b, l);
    x = remontee(n, y, d, u);
end

function y = descente(n, b, l)
    y = zeros(n, 1);

    y(1) = b(1);

    for i = 2:n
        y(i) = b(i) - l(i-1) * y(i-1);
    end
end


function x = remontee(n, y, d, u)
    x = zeros(n, 1);

    x(n) = y(n) / d(n);

    for i = (n-1):-1:1
        x(i) = (y(i) - u(i) * x(i+1)) / d(i);
    end
end

